require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xazuresqldatabase',
  dscmeta_resource_friendly_name: 'xAzureSqlDatabase',
  dscmeta_resource_name: 'MSFT_xAzureSqlDatabase',
  dscmeta_module_name: 'xAzure',
  dscmeta_module_version: '0.2.0.0',
  docs: 'The DSC xAzureSqlDatabase resource type.
         Automatically generated from version 0.2.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_servercredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credential to the database server',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_servername: {
      type: 'String',
      desc: 'Name of the database server',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Ensure that database is present or absent',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maximumsizeingb: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum size of the database in GB',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_azurepublishsettingsfile: {
      type: 'Optional[String]',
      desc: 'Specifies the location of the Publish Settings file for the Azure Subscription',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_edition: {
      type: 'Optional[String]',
      desc: 'Edition of the database',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the database',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_azuresubscriptionname: {
      type: 'Optional[String]',
      desc: 'Specifies the name of the Azure subscription that should be set to Current',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_collation: {
      type: 'Optional[String]',
      desc: 'Collation of the database',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
