require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xazurestorageaccount',
  dscmeta_resource_friendly_name: 'xAzureStorageAccount',
  dscmeta_resource_name: 'MSFT_xAzureStorageAccount',
  dscmeta_module_name: 'xAzure',
  dscmeta_module_version: '0.2.0.0',
  docs: 'The DSC xAzureStorageAccount resource type.
         Automatically generated from version 0.2.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_container: {
      type: 'Optional[String]',
      desc: 'Specifies a name for the Container that should be created in the Azure Storage Account.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_storageaccountname: {
      type: 'String',
      desc: 'Specifies a name for the storage account. The storage account name must be unique to Windows Azure and must be between 3 and 24 characters in length and use lowercase letters and numbers only.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies whether the Azure Storage Account should be present or absent.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_label: {
      type: 'Optional[String]',
      desc: 'Specifies a label for the storage account. The label may be up to 100 characters in length.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_affinitygroup: {
      type: 'String',
      desc: 'Specifies the name of an existing affinity group in the current subscription. You can specify either a Location or an AffinityGroup parameter, but not both. ',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_folder: {
      type: 'Optional[String]',
      desc: 'Specifies a local folder.  All files in the root of the folder will be uploaded to the new container.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
