require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xazurevm',
  dscmeta_resource_friendly_name: 'xAzureVM',
  dscmeta_resource_name: 'MSFT_xAzureVM',
  dscmeta_module_name: 'xAzure',
  dscmeta_module_version: '0.2.0.0',
  docs: 'The DSC xAzureVM resource type.
         Automatically generated from version 0.2.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_extensionscriptname: {
      type: 'Optional[String]',
      desc: 'Name of one of the files in the container that will be exectued at startup.  Case sensitive.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_extensionfilelist: {
      type: 'Optional[String]',
      desc: 'List of files in Azure Blob container that should be copied in to the VM.  Case sensitive.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_extensioncontainername: {
      type: 'Optional[String]',
      desc: 'The name of the Container in Azure Blob storage where the script files will reside.  Case sensitive.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'Specifies the name of the virtual machine.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies whether the Azure VM should be present or absent.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_linux: {
      type: 'Optional[Boolean]',
      desc: 'Creates a Linux virtual machine.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_instancesize: {
      type: 'Optional[String]',
      desc: 'Specifies the size of the instance.   For a list of virtual machine sizes, see http://msdn.microsoft.com/library/azure/dn197896.aspx',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_storageaccountname: {
      type: 'String',
      desc: 'Specifies the name of the storage account for the VM.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_servicename: {
      type: 'String',
      desc: 'Specifies the new or existing service name.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_imagename: {
      type: 'String',
      desc: 'Specifies the name of the operating system image to use to create the operating system disk.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_windows: {
      type: 'Optional[Boolean]',
      desc: 'Creates a Windows virtual machine.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
