require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xazurevmdscextension',
  dscmeta_resource_friendly_name: 'xAzureVMDscExtension',
  dscmeta_resource_name: 'MSFT_xAzureVMDscExtension',
  dscmeta_module_name: 'xAzure',
  dscmeta_module_version: '0.2.0.0',
  docs: 'The DSC xAzureVMDscExtension resource type.
         Automatically generated from version 0.2.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_referencename: {
      type: 'Optional[String]',
      desc: 'The Extension Reference Name',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_servicename: {
      type: 'String',
      desc: 'Specifies name of the Service where the VM is deployed.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_configurationdatapath: {
      type: 'Optional[String]',
      desc: 'The path to a .psd1 file that specifies the data for the configuration function.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_timestamp: {
      type: 'Optional[String]',
      desc: 'Returns the timestamp of the last DSC Extension execution.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_containername: {
      type: 'Optional[String]',
      desc: 'Name of the Azure Storage Container where the ConfigurationArchive is located.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_version: {
      type: 'Optional[String]',
      desc: 'The specific version of the DSC Extension to use. If not given, it will default to 1.*',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_configurationarchive: {
      type: 'String',
      desc: 'The name of the configuration package .zip file that was previously uploaded by Publish-AzureVMDscConfiguration. This parameter must specify only the name of the file, without any path.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_configurationargument: {
      type: 'Optional[Struct[{
              key => Optional[String],
              value => Optional[String],
            }]]',
      desc: 'A hashtable specifying the arguments to the configuration function. The keys correspond to the parameter names and the values to the parameter values.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_KeyValuePair',
      mof_is_embedded: true,
    },
    dsc_message: {
      type: 'Optional[String]',
      desc: 'Returns the formatted message string for the latest operation by the DSC Extension.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_storageaccountname: {
      type: 'String',
      desc: 'Specifies the name of the Storage Account used to create the Storage Context.  The Azure Storage Context provides the security settings used to access the configuration script. This context should provide read access to the container specified by ContainerName.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_status: {
      type: 'Optional[String]',
      desc: 'Returns the state of the DSC Extension from Azure.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_storageendpointsuffix: {
      type: 'Optional[String]',
      desc: 'The DNS endpoint suffix for all storage services, e.g. core.windows.net',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_code: {
      type: 'Optional[String]',
      desc: 'Returns the message code for the latest oepration by the DSC Extension.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_vmname: {
      type: 'String',
      desc: 'Specifies name of the VM.  This is used together with ServiceName to construct a persistent vm object.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_force: {
      type: 'Optional[Boolean]',
      desc: 'By default Set-AzureVMDscExtension will not overwrite any existing blobs. Use -Force to overwrite them.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_configuration: {
      type: 'Optional[String]',
      desc: 'Name of the configuration script or module that will be invoked by the DSC Extension.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
